import { world } from '@minecraft/server';

/**
 * Fonction pour gérer les rangs et les messages de chat personnalisés.
 * 
 * @param {import('@minecraft/server').ChatSendBeforeEvent} event - L'événement de chat.
 */
function chatrank(event) {
    const tags = event.sender.getTags(); // Récupérer les tags du joueur
    
    // Filtrer les tags pour obtenir les rangs
    let ranks = tags.filter(tag => tag.startsWith('rank:')).map(tag => tag.replace('rank:', ''));
    
    // S'il n'y a pas de rang, définir le rang par défaut à "Joueur"
    ranks = ranks.length ? ranks : ["§6Member"];
    
    // Si le message commence par "!*", annuler l'événement
    if (event.message.startsWith("!*")) {
        event.cancel = true; // Annuler l'événement
        return;
    }
    
    // Créer le texte de chat personnalisé
    const text = `§f[${ranks.join("§r§f] [")}§r§f] §7${event.sender.nameTag} : §f${event.message}`;
    
    // Envoyer le message à tous les joueurs en utilisant tellraw
    world.getDimension("overworld").runCommandAsync(`tellraw @a {"rawtext":[{"text":"${text}"}]}`);
    
    // Annuler l'événement de chat original pour éviter un double message
    event.cancel = true;
}

// Écouter l'événement chatSend et appeler la fonction chatrank
world.beforeEvents.chatSend.subscribe(chatrank);

// Exporter la fonction si vous voulez l'utiliser ailleurs
export { chatrank };